@@ -1,7 +1,7 @@
 /*
     SWARM
 
-    Copyright (C) 2012-2024 Torbjorn Rognes and Frederic Mahe
+    Copyright (C) 2012-2025 Torbjorn Rognes and Frederic Mahe
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Affero General Public License as
@@ -26,7 +26,7 @@
 #include <array>
 #include <cassert>  // assert()
 #include <cstdint>  // int64_t, uint64_t
-#include <cstdio>  // snprintf, size_t
+#include <cstdio>  // snprintf
 #include <vector>
 
 
@@ -37,9 +37,9 @@ constexpr unsigned char maskextup   = 4;
 constexpr unsigned char maskextleft = 8;
 
 
-auto align(char * dseq,
+auto align(char const * dseq,
            const uint64_t dlen,
-           char * qseq,
+           char const * qseq,
            const uint64_t qlen,
            const std::array<int64_t, n_cells * n_cells> & score_matrix,
            const uint64_t gapopen,
@@ -65,8 +65,8 @@ auto align(char * dseq,
   // then modified through a pointer; can't be const)
   for(auto column = 0UL; column < qlen; ++column)
     {
-      hearray[2 * column]     = 1 * gapopen + (column + 1) * gapextend; // H (N)
-      hearray[2 * column + 1] = 2 * gapopen + (column + 2) * gapextend; // E
+      hearray[2 * column]     = (1 * gapopen) + ((column + 1) * gapextend); // H (N)
+      hearray[(2 * column) + 1] = (2 * gapopen) + ((column + 2) * gapextend); // E
     }
 
   uint64_t previous_diagonal {0};
@@ -75,12 +75,12 @@ auto align(char * dseq,
   for(auto row = 0UL; row < dlen; ++row)
     {
       auto he_index = 0UL;
-      auto top = 2 * gapopen + (row + 2) * gapextend;
-      uint64_t diagonal = (row == 0) ? 0 : (gapopen + row * gapextend);
+      auto top = (2 * gapopen) + ((row + 2) * gapextend);
+      uint64_t diagonal = (row == 0) ? 0 : (gapopen + (row * gapextend));
 
       for(auto column = 0UL; column < qlen; ++column)
         {
-          const auto index = qlen * row + column;
+          const auto index = (qlen * row) + column;
 
           previous_diagonal = hearray[he_index];
           left = hearray[he_index + 1];
@@ -112,9 +112,9 @@ auto align(char * dseq,
 }
 
 
-auto backtrack(char * dseq,
+auto backtrack(char const * dseq,
                const uint64_t dlen,
-               char * qseq,
+               char const * qseq,
                const uint64_t qlen,
                uint64_t & nwdiff,
                std::vector<unsigned char> const & directions,
@@ -132,7 +132,7 @@ auto backtrack(char * dseq,
 
   while ((column > 0) and (row > 0))
     {
-      const auto cell = directions[qlen * (row - 1) + (column - 1)];
+      const auto cell = directions[(qlen * (row - 1)) + (column - 1)];
 
       ++alength;
 
@@ -234,9 +234,9 @@ auto backtrack(char * dseq,
 
 */
 
-auto nw(char * dseq,
+auto nw(char const * dseq,
         const uint64_t dlen,
-        char * qseq,
+        char const * qseq,
         const uint64_t qlen,
         const std::array<int64_t, n_cells * n_cells> & score_matrix,
         const uint64_t gapopen,
