@@ -1,7 +1,7 @@
 /*
     SWARM
 
-    Copyright (C) 2012-2024 Torbjorn Rognes and Frederic Mahe
+    Copyright (C) 2012-2025 Torbjorn Rognes and Frederic Mahe
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Affero General Public License as
@@ -29,9 +29,9 @@
 // refactor: 'n_cells' is already defined in 'score_matrix.h'
 constexpr auto n_cells_ = 32ULL;  // number of chars in sym_nt
 
-auto nw(char * dseq,
+auto nw(char const * dseq,
         uint64_t dlen,
-        char * qseq,
+        char const * qseq,
         uint64_t qlen,
         const std::array<int64_t, n_cells_ * n_cells_> & score_matrix,
         uint64_t gapopen,
