@@ -1,7 +1,7 @@
 /*
     SWARM
 
-    Copyright (C) 2012-2024 Torbjorn Rognes and Frederic Mahe
+    Copyright (C) 2012-2025 Torbjorn Rognes and Frederic Mahe
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Affero General Public License as
@@ -25,7 +25,7 @@
 #include <vector>
 
 
-auto findqgrams(unsigned char * seq, uint64_t seqlen,
+auto findqgrams(char const * seq, uint64_t seqlen,
                 unsigned char * qgramvector) -> void;
 auto qgram_diff(uint64_t seqno_a, uint64_t seqno_b) -> uint64_t;
 auto qgram_diff_fast(uint64_t seed,
