@@ -1,7 +1,7 @@
 /*
     SWARM
 
-    Copyright (C) 2012-2024 Torbjorn Rognes and Frederic Mahe
+    Copyright (C) 2012-2025 Torbjorn Rognes and Frederic Mahe
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Affero General Public License as
@@ -154,7 +154,7 @@ inline auto dprofile_fill8(BYTE * dprofile,
     {
       std::array<unsigned int, channels> d {{}};  // refactoring: name?
       for(auto i = 0U; i < channels; ++i) {
-        d[i] = (static_cast<unsigned int>(*std::next(dseq, j * channels + i))) << multiplier;
+        d[i] = (static_cast<unsigned int>(*std::next(dseq, (j * channels) + i))) << multiplier;
       }
 
       reg0  = v_load_64(std::next(score_matrix, d[pos0]));
@@ -214,14 +214,15 @@ inline auto dprofile_fill8(BYTE * dprofile,
       reg6  = v_merge_lo_64(reg6, reg14);
       reg15 = v_merge_hi_64(reg15, reg14);
 
-      v_store8(cast_vector8(std::next(dprofile, n_lanes * j + line0)), reg0);
-      v_store8(cast_vector8(std::next(dprofile, n_lanes * j + line1)), reg3);
-      v_store8(cast_vector8(std::next(dprofile, n_lanes * j + line2)), reg2);
-      v_store8(cast_vector8(std::next(dprofile, n_lanes * j + line3)), reg7);
-      v_store8(cast_vector8(std::next(dprofile, n_lanes * j + line4)), reg1);
-      v_store8(cast_vector8(std::next(dprofile, n_lanes * j + line5)), reg11);
-      v_store8(cast_vector8(std::next(dprofile, n_lanes * j + line6)), reg6);
-      v_store8(cast_vector8(std::next(dprofile, n_lanes * j + line7)), reg15);
+      std::ptrdiff_t const lane = n_lanes * j;  // refactoring: meaningful name?
+      v_store8(cast_vector8(std::next(dprofile, lane + line0)), reg0);
+      v_store8(cast_vector8(std::next(dprofile, lane + line1)), reg3);
+      v_store8(cast_vector8(std::next(dprofile, lane + line2)), reg2);
+      v_store8(cast_vector8(std::next(dprofile, lane + line3)), reg7);
+      v_store8(cast_vector8(std::next(dprofile, lane + line4)), reg1);
+      v_store8(cast_vector8(std::next(dprofile, lane + line5)), reg11);
+      v_store8(cast_vector8(std::next(dprofile, lane + line6)), reg6);
+      v_store8(cast_vector8(std::next(dprofile, lane + line7)), reg15);
 
 
       // loads not aligned on 16 byte boundary, cannot load and unpack in one instr.
@@ -291,14 +292,14 @@ inline auto dprofile_fill8(BYTE * dprofile,
       reg6  = v_merge_lo_64(reg6, reg14);
       reg15 = v_merge_hi_64(reg15, reg14);
 
-      v_store8(cast_vector8(std::next(dprofile, n_lanes * j + line8 + line0)), reg0);
-      v_store8(cast_vector8(std::next(dprofile, n_lanes * j + line8 + line1)), reg3);
-      v_store8(cast_vector8(std::next(dprofile, n_lanes * j + line8 + line2)), reg2);
-      v_store8(cast_vector8(std::next(dprofile, n_lanes * j + line8 + line3)), reg7);
-      v_store8(cast_vector8(std::next(dprofile, n_lanes * j + line8 + line4)), reg1);
-      v_store8(cast_vector8(std::next(dprofile, n_lanes * j + line8 + line5)), reg11);
-      v_store8(cast_vector8(std::next(dprofile, n_lanes * j + line8 + line6)), reg6);
-      v_store8(cast_vector8(std::next(dprofile, n_lanes * j + line8 + line7)), reg15);
+      v_store8(cast_vector8(std::next(dprofile, lane + line8 + line0)), reg0);
+      v_store8(cast_vector8(std::next(dprofile, lane + line8 + line1)), reg3);
+      v_store8(cast_vector8(std::next(dprofile, lane + line8 + line2)), reg2);
+      v_store8(cast_vector8(std::next(dprofile, lane + line8 + line3)), reg7);
+      v_store8(cast_vector8(std::next(dprofile, lane + line8 + line4)), reg1);
+      v_store8(cast_vector8(std::next(dprofile, lane + line8 + line5)), reg11);
+      v_store8(cast_vector8(std::next(dprofile, lane + line8 + line6)), reg6);
+      v_store8(cast_vector8(std::next(dprofile, lane + line8 + line7)), reg15);
 
 
       reg0  = v_load_64(std::next(score_matrix, offset16 + d[pos0]));
@@ -358,14 +359,14 @@ inline auto dprofile_fill8(BYTE * dprofile,
       reg6  = v_merge_lo_64(reg6, reg14);
       reg15 = v_merge_hi_64(reg15, reg14);
 
-      v_store8(cast_vector8(std::next(dprofile, n_lanes * j + line16 + line0)), reg0);
-      v_store8(cast_vector8(std::next(dprofile, n_lanes * j + line16 + line1)), reg3);
-      v_store8(cast_vector8(std::next(dprofile, n_lanes * j + line16 + line2)), reg2);
-      v_store8(cast_vector8(std::next(dprofile, n_lanes * j + line16 + line3)), reg7);
-      v_store8(cast_vector8(std::next(dprofile, n_lanes * j + line16 + line4)), reg1);
-      v_store8(cast_vector8(std::next(dprofile, n_lanes * j + line16 + line5)), reg11);
-      v_store8(cast_vector8(std::next(dprofile, n_lanes * j + line16 + line6)), reg6);
-      v_store8(cast_vector8(std::next(dprofile, n_lanes * j + line16 + line7)), reg15);
+      v_store8(cast_vector8(std::next(dprofile, lane + line16 + line0)), reg0);
+      v_store8(cast_vector8(std::next(dprofile, lane + line16 + line1)), reg3);
+      v_store8(cast_vector8(std::next(dprofile, lane + line16 + line2)), reg2);
+      v_store8(cast_vector8(std::next(dprofile, lane + line16 + line3)), reg7);
+      v_store8(cast_vector8(std::next(dprofile, lane + line16 + line4)), reg1);
+      v_store8(cast_vector8(std::next(dprofile, lane + line16 + line5)), reg11);
+      v_store8(cast_vector8(std::next(dprofile, lane + line16 + line6)), reg6);
+      v_store8(cast_vector8(std::next(dprofile, lane + line16 + line7)), reg15);
 
 
       // loads not aligned on 16 byte boundary, cannot load and unpack in one instr.
@@ -435,14 +436,14 @@ inline auto dprofile_fill8(BYTE * dprofile,
       reg6  = v_merge_lo_64(reg6, reg14);
       reg15 = v_merge_hi_64(reg15, reg14);
 
-      v_store8(cast_vector8(std::next(dprofile, n_lanes * j + line24 + line0)), reg0);
-      v_store8(cast_vector8(std::next(dprofile, n_lanes * j + line24 + line1)), reg3);
-      v_store8(cast_vector8(std::next(dprofile, n_lanes * j + line24 + line2)), reg2);
-      v_store8(cast_vector8(std::next(dprofile, n_lanes * j + line24 + line3)), reg7);
-      v_store8(cast_vector8(std::next(dprofile, n_lanes * j + line24 + line4)), reg1);
-      v_store8(cast_vector8(std::next(dprofile, n_lanes * j + line24 + line5)), reg11);
-      v_store8(cast_vector8(std::next(dprofile, n_lanes * j + line24 + line6)), reg6);
-      v_store8(cast_vector8(std::next(dprofile, n_lanes * j + line24 + line7)), reg15);
+      v_store8(cast_vector8(std::next(dprofile, lane + line24 + line0)), reg0);
+      v_store8(cast_vector8(std::next(dprofile, lane + line24 + line1)), reg3);
+      v_store8(cast_vector8(std::next(dprofile, lane + line24 + line2)), reg2);
+      v_store8(cast_vector8(std::next(dprofile, lane + line24 + line3)), reg7);
+      v_store8(cast_vector8(std::next(dprofile, lane + line24 + line4)), reg1);
+      v_store8(cast_vector8(std::next(dprofile, lane + line24 + line5)), reg11);
+      v_store8(cast_vector8(std::next(dprofile, lane + line24 + line6)), reg6);
+      v_store8(cast_vector8(std::next(dprofile, lane + line24 + line7)), reg15);
     }
 }
 
@@ -519,14 +520,14 @@ auto align_cells_regular_8(VECTORTYPE * Sm,
   for(auto pos = 0LL; pos < ql_signed; ++pos)
     {
       VECTORTYPE * x = *std::next(qp, pos + 0);
-      h4 = *std::next(hep, 2 * pos + 0);
-      E  = *std::next(hep, 2 * pos + 1);
-      onestep_8(h0, h5, f0, *std::next(x, 0), std::next(dir, step * pos + offset0), E, Q, R);
-      onestep_8(h1, h6, f1, *std::next(x, 1), std::next(dir, step * pos + offset1), E, Q, R);
-      onestep_8(h2, h7, f2, *std::next(x, 2), std::next(dir, step * pos + offset2), E, Q, R);
-      onestep_8(h3, h8, f3, *std::next(x, 3), std::next(dir, step * pos + offset3), E, Q, R);
-      *std::next(hep, 2 * pos + 0) = h8;
-      *std::next(hep, 2 * pos + 1) = E;
+      h4 = *std::next(hep, (2 * pos) + 0);
+      E  = *std::next(hep, (2 * pos) + 1);
+      onestep_8(h0, h5, f0, *std::next(x, 0), std::next(dir, (step * pos) + offset0), E, Q, R);
+      onestep_8(h1, h6, f1, *std::next(x, 1), std::next(dir, (step * pos) + offset1), E, Q, R);
+      onestep_8(h2, h7, f2, *std::next(x, 2), std::next(dir, (step * pos) + offset2), E, Q, R);
+      onestep_8(h3, h8, f3, *std::next(x, 3), std::next(dir, (step * pos) + offset3), E, Q, R);
+      *std::next(hep, (2 * pos) + 0) = h8;
+      *std::next(hep, (2 * pos) + 1) = E;
       h0 = h4;
       h1 = h5;
       h2 = h6;
@@ -590,8 +591,8 @@ auto align_cells_masked_8(VECTORTYPE * Sm,
   for(auto pos = 0LL; pos < ql_signed; ++pos)
     {
       VECTORTYPE * x = *std::next(qp, pos + 0);
-      h4 = *std::next(hep, 2 * pos + 0);
-      E  = *std::next(hep, 2 * pos + 1);
+      h4 = *std::next(hep, (2 * pos) + 0);
+      E  = *std::next(hep, (2 * pos) + 1);
 
       /* mask h4 and E */
       h4 = v_sub8(h4, *Mm);
@@ -605,12 +606,12 @@ auto align_cells_masked_8(VECTORTYPE * Sm,
       /* update MQ */
       *MQ = v_add8(*MQ,  *MR);
 
-      onestep_8(h0, h5, f0, *std::next(x, 0), std::next(dir, step * pos + offset0), E, Q, R);
-      onestep_8(h1, h6, f1, *std::next(x, 1), std::next(dir, step * pos + offset1), E, Q, R);
-      onestep_8(h2, h7, f2, *std::next(x, 2), std::next(dir, step * pos + offset2), E, Q, R);
-      onestep_8(h3, h8, f3, *std::next(x, 3), std::next(dir, step * pos + offset3), E, Q, R);
-      *std::next(hep, 2 * pos + 0) = h8;
-      *std::next(hep, 2 * pos + 1) = E;
+      onestep_8(h0, h5, f0, *std::next(x, 0), std::next(dir, (step * pos) + offset0), E, Q, R);
+      onestep_8(h1, h6, f1, *std::next(x, 1), std::next(dir, (step * pos) + offset1), E, Q, R);
+      onestep_8(h2, h7, f2, *std::next(x, 2), std::next(dir, (step * pos) + offset2), E, Q, R);
+      onestep_8(h3, h8, f3, *std::next(x, 3), std::next(dir, (step * pos) + offset3), E, Q, R);
+      *std::next(hep, (2 * pos) + 0) = h8;
+      *std::next(hep, (2 * pos) + 1) = E;
 
       h0 = h4;
       h1 = h5;
@@ -650,7 +651,7 @@ auto search8(std::vector<BYTE *> & q_start,
   // nullptr for pointers, etc)
   std::array<uint64_t, channels> d_pos {{}};
   std::array<uint64_t, channels> d_offset {{}};
-  std::array<char *, channels> d_address {{}};
+  std::array<char const *, channels> d_address {{}};
   std::array<uint64_t, channels> d_length {{}};
   std::array<int64_t, channels> seq_id {{}};
   seq_id.fill(-1);
@@ -707,12 +708,12 @@ auto search8(std::vector<BYTE *> & q_start,
               for(auto j = 0U; j < cdepth; ++j)
                 {
                   if (d_pos[channel] < d_length[channel]) {
-                    dseq[channels * j + channel]
+                    dseq[(channels * j) + channel]
                       = 1 + nt_extract(d_address[channel], d_pos[channel]);
                     ++d_pos[channel];
                   }
                   else {
-                    dseq[channels * j + channel] = 0;
+                    dseq[(channels * j) + channel] = 0;
                   }
                 }
               if (d_pos[channel] == d_length[channel]) {
@@ -753,12 +754,12 @@ auto search8(std::vector<BYTE *> & q_start,
                   for(auto j = 0U; j < cdepth; ++j)
                     {
                       if (d_pos[channel] < d_length[channel]) {
-                        dseq[channels * j + channel]
+                        dseq[(channels * j) + channel]
                           = 1 + nt_extract(d_address[channel], d_pos[channel]);
                         ++d_pos[channel];
                       }
                       else {
-                        dseq[channels * j + channel] = 0;
+                        dseq[(channels * j) + channel] = 0;
                       }
                     }
                   if (d_pos[channel] == d_length[channel]) {
@@ -778,12 +779,12 @@ auto search8(std::vector<BYTE *> & q_start,
                     {
                       // save score
 
-                      char * dbseq = d_address[channel];
+                      char const * dbseq = d_address[channel];
                       const uint64_t dbseqlen = d_length[channel];
                       const uint64_t z = (dbseqlen + 3) % 4;
                       assert(z * channels + channel <= max_ptrdiff);
                       const uint64_t score
-                        = *std::next(reinterpret_cast<BYTE *>(S), static_cast<std::ptrdiff_t>(z * channels + channel));
+                        = *std::next(reinterpret_cast<BYTE *>(S), static_cast<std::ptrdiff_t>((z * channels) + channel));
                       *std::next(scores, cand_id) = score;
 
                       uint64_t diff {0};
@@ -815,7 +816,7 @@ auto search8(std::vector<BYTE *> & q_start,
                       assert(next_id <= max_ptrdiff);
                       seq_id[channel] = static_cast<int64_t>(next_id);
                       const uint64_t seqno = *std::next(seqnos, static_cast<std::ptrdiff_t>(next_id));
-                      char * address {nullptr};
+                      char const * address {nullptr};
                       unsigned int length {0};
 
                       db_getsequenceandlength(seqno, address, length);
@@ -828,18 +829,18 @@ auto search8(std::vector<BYTE *> & q_start,
                       ++next_id;
 
                       *std::next(reinterpret_cast<BYTE *>(&H0), channel) = 0;
-                      assert(2U * gap_open_penalty + 2U * gap_extend_penalty <= std::numeric_limits<BYTE>::max());
-                      *std::next(reinterpret_cast<BYTE *>(&F0), channel) = static_cast<BYTE>(2U * gap_open_penalty + 2U * gap_extend_penalty);
+                      assert((2U * gap_open_penalty) + (2U * gap_extend_penalty) <= std::numeric_limits<BYTE>::max());
+                      *std::next(reinterpret_cast<BYTE *>(&F0), channel) = static_cast<BYTE>((2U * gap_open_penalty) + (2U * gap_extend_penalty));
 
                       // fill channel
                       for(auto j = 0U; j < cdepth; ++j)
                         {
                           if (d_pos[channel] < d_length[channel]) {
-                            dseq[channels * j + channel] = 1 + nt_extract(d_address[channel], d_pos[channel]);
+                            dseq[(channels * j) + channel] = 1 + nt_extract(d_address[channel], d_pos[channel]);
                             ++d_pos[channel];
                           }
                           else {
-                            dseq[channels * j + channel] = 0;
+                            dseq[(channels * j) + channel] = 0;
                           }
                         }
                       if (d_pos[channel] == d_length[channel]) {
@@ -854,7 +855,7 @@ auto search8(std::vector<BYTE *> & q_start,
                       d_pos[channel] = 0;
                       d_length[channel] = 0;
                       for(auto j = 0U; j < cdepth; ++j) {
-                        dseq[channels * j + channel] = 0;
+                        dseq[(channels * j) + channel] = 0;
                       }
                     }
                 }
