@@ -1,7 +1,7 @@
 /*
     SWARM
 
-    Copyright (C) 2012-2024 Torbjorn Rognes and Frederic Mahe
+    Copyright (C) 2012-2025 Torbjorn Rognes and Frederic Mahe
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Affero General Public License as
@@ -84,16 +84,16 @@ auto dprofile_shuffle8(BYTE * dprofile,
   const auto seq_chunk2 = v_load8(std::next(sequence_db, 2));  // next 16
   const auto seq_chunk3 = v_load8(std::next(sequence_db, 3));  // final 16 (total of 64)
 
-  auto profline8 = [&](const long long int nuc) {
+  auto profline8 = [&](const long long int nuc) -> void {
     // scores: 16 scores from the score matrix, matching the
     // nucleotide 'nuc'; five different nucleotides (0, 1, 2, 3, 4),
     // so five possible rows of scores
     const auto scores = v_load8(std::next(score_db, 2 * nuc));
 
-    v_store8(std::next(profile_db, 4 * nuc + 0), v_shuffle8(scores, seq_chunk0));
-    v_store8(std::next(profile_db, 4 * nuc + 1), v_shuffle8(scores, seq_chunk1));
-    v_store8(std::next(profile_db, 4 * nuc + 2), v_shuffle8(scores, seq_chunk2));
-    v_store8(std::next(profile_db, 4 * nuc + 3), v_shuffle8(scores, seq_chunk3));
+    v_store8(std::next(profile_db, (4 * nuc) + 0), v_shuffle8(scores, seq_chunk0));
+    v_store8(std::next(profile_db, (4 * nuc) + 1), v_shuffle8(scores, seq_chunk1));
+    v_store8(std::next(profile_db, (4 * nuc) + 2), v_shuffle8(scores, seq_chunk2));
+    v_store8(std::next(profile_db, (4 * nuc) + 3), v_shuffle8(scores, seq_chunk3));
   };
 
   profline8(0);  // -/gap/no nucleotide (0)
@@ -144,13 +144,13 @@ auto dprofile_shuffle16(WORD * dprofile,
   const auto m2 = transform_lower_seq_chunk(t3);
   const auto m3 = transform_higher_seq_chunk(t3);
 
-  auto profline16 = [&](const long long int nuc) {
+  auto profline16 = [&](const long long int nuc) -> void {
     const auto scores = v_load16(std::next(score_db, 4 * nuc));
 
-    v_store16(std::next(profile_db, 4 * nuc + 0), v_shuffle8(scores, m0));
-    v_store16(std::next(profile_db, 4 * nuc + 1), v_shuffle8(scores, m1));
-    v_store16(std::next(profile_db, 4 * nuc + 2), v_shuffle8(scores, m2));
-    v_store16(std::next(profile_db, 4 * nuc + 3), v_shuffle8(scores, m3));
+    v_store16(std::next(profile_db, (4 * nuc) + 0), v_shuffle8(scores, m0));
+    v_store16(std::next(profile_db, (4 * nuc) + 1), v_shuffle8(scores, m1));
+    v_store16(std::next(profile_db, (4 * nuc) + 2), v_shuffle8(scores, m2));
+    v_store16(std::next(profile_db, (4 * nuc) + 3), v_shuffle8(scores, m3));
   };
 
   profline16(0);  // -/gap/no nucleotide (0)
