@@ -1,7 +1,7 @@
 /*
     SWARM
 
-    Copyright (C) 2012-2024 Torbjorn Rognes and Frederic Mahe
+    Copyright (C) 2012-2025 Torbjorn Rognes and Frederic Mahe
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Affero General Public License as
@@ -44,7 +44,7 @@
 #include <cinttypes>  // macros PRIu64 and PRId64
 #include <cstdint>  // int64_t
 #include <cstdio>  // FILE, fclose, stderr  // refactoring: replace with <fstream>
-#include <cstdlib>  // std::exit
+#include <cstdlib>  // std::exit, std::strtol
 #include <getopt.h>  // getopt_long, optarg, optind, opterr, struct
                      // option (no_argument, required_argument)
 #include <iterator>  // std::next
@@ -62,10 +62,17 @@ constexpr char PRId64[] = "ld";
 #endif
 
 
+// anonymous namespace: limit visibility and usage to this translation unit
+namespace {
+
+
+}  // end of anonymous namespace
+
+
 constexpr auto int_max = std::numeric_limits<int>::max();
 constexpr auto int16_max = std::numeric_limits<int16_t>::max();
 static_assert(int_max > int16_max, "Your compiler uses very short integers.");
-const std::string swarm_version {"3.1.5"};
+const std::string swarm_version {"3.1.6"};
 
 
 /* OPTIONS */
@@ -120,7 +127,7 @@ const std::array<struct option, 25> long_options = {
 const std::vector<std::string> header_message
   {"Swarm ", swarm_version,
    "\n",
-   "Copyright (C) 2012-2024 Torbjorn Rognes and Frederic Mahe\n",
+   "Copyright (C) 2012-2025 Torbjorn Rognes and Frederic Mahe\n",
    "https://github.com/torognes/swarm\n",
    "\n",
    "Mahe F, Rognes T, Quince C, de Vargas C, Dunthorn M (2014)\n",
@@ -183,12 +190,12 @@ const std::vector<std::string> args_usage_message
   };
 
 
-auto args_long(char * str, const char * option) -> int64_t
+auto args_long(char const * str, const char * option) -> int64_t
 {
   static constexpr int base_value {10};
   char * endptr {nullptr};
-  const int64_t number = strtol(str, & endptr, base_value);
-  if (*endptr != 0)
+  const int64_t number = std::strtol(str, & endptr, base_value);
+  if (*endptr != '\0')
     {
       fatal(error_prefix, "Invalid numeric argument for option ", option, ".\n\n",
             "Frequent causes are:\n",
@@ -309,7 +316,7 @@ auto args_init(int argc, char **argv, struct Parameters & parameters) -> std::ar
         used_options[optindex] = true;
       }
 
-    switch(option_character)
+    switch (option_character)
       {
       case 'a':  // refactoring: replace with enum class? static_cast<Short_option>(option_character), but what about unexpected characters such as 'k' or 'q'?
         /* append-abundance */
@@ -447,12 +454,21 @@ auto args_init(int argc, char **argv, struct Parameters & parameters) -> std::ar
     parameters.input_filename = *std::next(argv, optind);
   }
 
-  // scoring system
-  parameters.penalty_mismatch = 2 * parameters.opt_match_reward + 2 * parameters.opt_mismatch_penalty;
+#ifdef __x86_64__
+  cpu_features_detect(parameters);
+  cpu_features_test(parameters);
+#endif
+
+  return used_options;
+}
+
+
+auto set_alignment_scoring_system(struct Parameters &parameters) -> void {
+  parameters.penalty_mismatch = (2 * parameters.opt_match_reward) + (2 * parameters.opt_mismatch_penalty);
   penalty_mismatch = parameters.penalty_mismatch;
   parameters.penalty_gapopen = 2 * parameters.opt_gap_opening_penalty;
   penalty_gapopen = parameters.penalty_gapopen;
-  parameters.penalty_gapextend = parameters.opt_match_reward + 2 * parameters.opt_gap_extension_penalty;
+  parameters.penalty_gapextend = parameters.opt_match_reward + (2 * parameters.opt_gap_extension_penalty);
   penalty_gapextend = parameters.penalty_gapextend;
 
   const int64_t penalty_factor {gcd(gcd(parameters.penalty_mismatch, parameters.penalty_gapopen), parameters.penalty_gapextend)};
@@ -464,13 +480,6 @@ auto args_init(int argc, char **argv, struct Parameters & parameters) -> std::ar
   penalty_gapopen = parameters.penalty_gapopen;
   parameters.penalty_gapextend /= penalty_factor;
   penalty_gapextend = parameters.penalty_gapextend;
-
-#ifdef __x86_64__
-  cpu_features_detect(parameters);
-  cpu_features_test(parameters);
-#endif
-
-  return used_options;
 }
 
 
@@ -626,13 +635,14 @@ auto main(int argc, char** argv) -> int
   // initialization and checks
   struct Parameters parameters;
   const auto used_options = args_init(argc, argv, parameters);
+  set_alignment_scoring_system(parameters);
   args_check(used_options, parameters);
   open_files(parameters);
   show(header_message, parameters.logfile);
   args_show(parameters);
 
   // parse fasta input
-  std::vector<char> data_v;  // refactoring: std::string fails? .data() -> const char *
+  std::vector<char> data_v;  // refactoring: std::string fails? .data() -> const char *  // alignas(8) does not fix alignment issue
   std::vector<struct seqinfo_s> seqindex_v;
   std::vector<uint64_t> zobrist_tab_base_v;
   std::vector<uint64_t> zobrist_tab_byte_base_v;
