@@ -1,7 +1,7 @@
 /*
     SWARM
 
-    Copyright (C) 2012-2023 Torbjorn Rognes and Frederic Mahe
+    Copyright (C) 2012-2025 Torbjorn Rognes and Frederic Mahe
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Affero General Public License as
@@ -22,7 +22,7 @@
 */
 
 #include <cstdint>  // int64_t, uint64_t
-#include <cstdio>  // FILE
+#include <cstdio>  // FILE, stderr
 #include <string>
 
 
@@ -37,34 +37,22 @@
 // will be de-duplicated by the linker.
 // (source: https://www.youtube.com/watch?v=QVHwOOrSh3w)
 
-const std::string swarm_version {"3.1.4"};
-constexpr char sepchar {' '};
 constexpr char dash_filename {'-'};
 constexpr unsigned int opt_differences_default {1};
 constexpr unsigned int ceiling_default {0};
+constexpr auto boundary_default = 3;
 constexpr unsigned int append_abundance_default {0};
 constexpr unsigned int mismatch_penalty_default {4};
 constexpr unsigned int match_reward_default {5};
-constexpr unsigned int gap_opening_penalty_default {12};
+constexpr auto gap_opening_penalty_default = 12L;
 constexpr unsigned int gap_extension_penalty_default {4};
 constexpr unsigned int bloom_bits_default {16};
 
 
-/* structures and data types */
-
-struct queryinfo
-{
-  uint64_t qno;
-  int64_t len;
-  char * seq;
-};
-
-using queryinfo_t = struct queryinfo;
-extern queryinfo_t query;
-
 /* common data */
 
 struct Parameters {
+  int64_t opt_threads {1};
   int64_t opt_bloom_bits {bloom_bits_default};
   int64_t opt_differences {opt_differences_default};
   int64_t opt_mismatch_penalty {mismatch_penalty_default};
@@ -73,6 +61,7 @@ struct Parameters {
   int64_t opt_gap_extension_penalty {gap_extension_penalty_default};
   int64_t opt_ceiling {ceiling_default};
   int64_t opt_append_abundance {append_abundance_default};
+  int64_t opt_boundary {boundary_default};
   int64_t mmx_present {0};
   int64_t sse42_present {0};
   int64_t sse_present {0};
@@ -80,13 +69,21 @@ struct Parameters {
   int64_t avx2_present {0};
   int64_t avx_present {0};
   int64_t sse3_present {0};
-  int64_t penalty_mismatch {2 * match_reward_default + 2 * mismatch_penalty_default};
+  int64_t sse41_present {0};
+  int64_t ssse3_present {0};
+  int64_t popcnt_present {0};
+  int64_t penalty_mismatch {(2 * match_reward_default) +
+                            (2 * mismatch_penalty_default)};
+  int64_t penalty_gapextend {match_reward_default +
+                             (2 * gap_extension_penalty_default)};
+  int64_t penalty_gapopen {2 * gap_opening_penalty_default};
   bool opt_help {false};
   bool opt_disable_sse3 {false};
   bool opt_version {false};
   bool opt_fastidious {false};
   bool opt_usearch_abundance {false};
   bool opt_mothur {false};
+  bool opt_no_cluster_breaking {false};
   std::string input_filename {dash_filename};
   std::string opt_network_file;
   std::string opt_internal_structure;
@@ -94,32 +91,12 @@ struct Parameters {
   std::string opt_statistics_file;
   std::string opt_uclust_file;
   std::string opt_output_file {dash_filename};
+  std::string opt_log;
+  std::FILE * outfile {nullptr};
+  std::FILE * statsfile {nullptr};
+  std::FILE * uclustfile {nullptr};
+  std::FILE * internal_structure_file {nullptr};
+  std::FILE * seeds_file {nullptr};
+  std::FILE * network_file {nullptr};
+  std::FILE * logfile {stderr};  // stderr macro expands to type std::FILE*
 };
-
-// Note: extern - static storage duration and external linkage
-//
-// Objects of static storage duration are zero-initialized before
-// main() is called (verified in gdb). However, it seems that the
-// linker requires these objects to be explicitly initialized in one
-// of the translation units.
-
-extern std::string opt_log;  // used by multithreaded functions
-extern int64_t opt_boundary;  // used by multithreaded functions
-extern bool opt_no_otu_breaking;  // three function calls
-extern int64_t opt_threads;
-
-extern int64_t penalty_gapextend;
-extern int64_t penalty_gapopen;
-extern int64_t penalty_mismatch;
-
-extern std::FILE * outfile;
-extern std::FILE * statsfile;
-extern std::FILE * uclustfile;
-extern std::FILE * internal_structure_file;
-extern std::FILE * logfile;
-extern std::FILE * fp_seeds;
-extern std::FILE * network_file;
-
-extern int64_t ssse3_present; // several function calls
-extern int64_t sse41_present; // several function calls
-extern int64_t popcnt_present; // several function calls
