@@ -1,7 +1,7 @@
 /*
     SWARM
 
-    Copyright (C) 2012-2024 Torbjorn Rognes and Frederic Mahe
+    Copyright (C) 2012-2025 Torbjorn Rognes and Frederic Mahe
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Affero General Public License as
@@ -27,11 +27,9 @@
 #include <cstring>  // strcmp
 
 
-constexpr std::size_t memalignment = 16;
-
-
 auto xmalloc(std::size_t size) -> void *
 {
+  static constexpr std::size_t memalignment = 16;
   if (size == 0) {
     size = 1;
   }
@@ -50,23 +48,6 @@ auto xmalloc(std::size_t size) -> void *
 }
 
 
-auto xrealloc(void *ptr, std::size_t size) -> void *
-{
-  if (size == 0) {
-    size = 1;
-  }
-#ifdef _WIN32
-  void * memptr = _aligned_realloc(ptr, size, memalignment);
-#else
-  void * memptr = std::realloc(ptr, size);
-#endif
-  if (memptr == nullptr) {
-    fatal(error_prefix, "Unable to allocate enough memory.");
-  }
-  return memptr;
-}
-
-
 auto xfree(void * ptr) -> void
 {
   if (ptr != nullptr)
@@ -83,6 +64,7 @@ auto xfree(void * ptr) -> void
 }
 
 
+// refactoring: std::getline(input, str) -> input
 auto xgetline(char ** linep, std::size_t * linecapp, std::FILE * stream) -> ssize_t
 {
 #ifndef _WIN32
@@ -102,8 +84,8 @@ auto xgetline(char ** linep, std::size_t * linecapp, std::FILE * stream) -> ssiz
      which is important for correct counting of characters and file size.
   */
 
-  const std::size_t minsize = 2;
-  const std::size_t maxsize = SIZE_MAX / 2;
+  static constexpr std::size_t minsize = 2;
+  static constexpr std::size_t maxsize = SIZE_MAX / 2;
 
   /* Error if linep or linecapp pointers are null */
   if ((linep == nullptr) or (linecapp == nullptr))
@@ -126,12 +108,12 @@ auto xgetline(char ** linep, std::size_t * linecapp, std::FILE * stream) -> ssiz
   std::size_t len = 0;
   *p = 0;
 
-  while (1)
+  while (true)
     {
       while (p < e)
         {
           int c = getc(stream);
-          switch(c)
+          switch (c)
             {
             case -1:
               if (feof(stream))
