@@ -1,7 +1,7 @@
 /*
     SWARM
 
-    Copyright (C) 2012-2024 Torbjorn Rognes and Frederic Mahe
+    Copyright (C) 2012-2025 Torbjorn Rognes and Frederic Mahe
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Affero General Public License as
@@ -22,7 +22,7 @@
 */
 
 #include <cstdlib>
-#include <iostream>
+#include <iostream>  // replace with std::printf for performance?
 
 [[noreturn]]
 auto fatal() -> void {
