@@ -1,7 +1,7 @@
 /*
     SWARM
 
-    Copyright (C) 2012-2024 Torbjorn Rognes and Frederic Mahe
+    Copyright (C) 2012-2025 Torbjorn Rognes and Frederic Mahe
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Affero General Public License as
@@ -24,6 +24,6 @@
 #include <cstdint>  // uint64_t
 
 
-auto nt_extract(char * seq, uint64_t pos) -> unsigned char;
+auto nt_extract(char const * seq, uint64_t pos) -> unsigned char;
 
 auto nt_bytelength(unsigned int len) -> unsigned int;
