@@ -1,7 +1,7 @@
 /*
     SWARM
 
-    Copyright (C) 2012-2024 Torbjorn Rognes and Frederic Mahe
+    Copyright (C) 2012-2025 Torbjorn Rognes and Frederic Mahe
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Affero General Public License as
@@ -28,7 +28,7 @@ struct queryinfo
 {
   uint64_t qno;
   int64_t len;
-  char * seq;
+  char const * seq;
 };
 
 extern struct queryinfo query;
