@@ -1,7 +1,7 @@
 /*
   SWARM
 
-  Copyright (C) 2012-2024 Torbjorn Rognes and Frederic Mahe
+  Copyright (C) 2012-2025 Torbjorn Rognes and Frederic Mahe
 
   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU Affero General Public License as
@@ -23,14 +23,17 @@
 
 #include <cstdint>  // uint64_t
 
+// refactoring: add View header_view and View seq_view to
+// progressively get rid of raw pointers
+
 struct seqinfo_s
 {
-  char * header;
-  char * seq;
+  char const * header;
+  char const * seq;
   uint64_t abundance;
   uint64_t hdrhash;
   uint64_t seqhash;
-  int headerlen;
+  int headerlen;  // refactoring: should be unsigned int or size_t
   unsigned int seqlen;
   unsigned int clusterid;
   int abundance_start;
