@@ -1,7 +1,7 @@
 /*
     SWARM
 
-    Copyright (C) 2012-2024 Torbjorn Rognes and Frederic Mahe
+    Copyright (C) 2012-2025 Torbjorn Rognes and Frederic Mahe
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Affero General Public License as
@@ -37,19 +37,19 @@ struct var_s
   unsigned short dummy; /* for alignment padding only */
 };
 
-auto generate_variant_sequence(char * seed_sequence,
+auto generate_variant_sequence(char const * seed_sequence,
                                unsigned int seed_seqlen,
                                struct var_s & var,
-                               std::vector<char>& seq,
+                               std::vector<char> & seq,
                                unsigned int & seqlen) -> void;
 
-auto check_variant(char * seed_sequence,
+auto check_variant(char const * seed_sequence,
                    unsigned int seed_seqlen,
                    struct var_s & var,
-                   char * amp_sequence,
+                   char const * amp_sequence,
                    unsigned int amp_seqlen) -> bool;
 
-auto generate_variants(char * sequence,
+auto generate_variants(char const * sequence,
                        unsigned int seqlen,
                        uint64_t hash,
-                       std::vector<struct var_s>& variant_list) -> unsigned int;
+                       std::vector<struct var_s> & variant_list) -> unsigned int;
