@@ -1,7 +1,7 @@
 /*
     SWARM
 
-    Copyright (C) 2012-2024 Torbjorn Rognes and Frederic Mahe
+    Copyright (C) 2012-2025 Torbjorn Rognes and Frederic Mahe
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Affero General Public License as
@@ -31,11 +31,11 @@ auto zobrist_init(unsigned int n,
 
 auto zobrist_exit() -> void;
 
-auto zobrist_hash(unsigned char * seq, unsigned int len) -> uint64_t;
+auto zobrist_hash(char const * seq, unsigned int len) -> uint64_t;
 
-auto zobrist_hash_delete_first(unsigned char * seq, unsigned int len) -> uint64_t;
+auto zobrist_hash_delete_first(char const * seq, unsigned int len) -> uint64_t;
 
-auto zobrist_hash_insert_first(unsigned char * seq, unsigned int len) -> uint64_t;
+auto zobrist_hash_insert_first(char const * seq, unsigned int len) -> uint64_t;
 
 auto zobrist_value(unsigned int pos, unsigned char offset) -> uint64_t;
 
